@@ -35,9 +35,9 @@
 #include <kdebug.h>
 #include <ktempfile.h>
 
-#include <iostream.h>
-#include <stdio.h>
-#include <stdlib.h>
+#include <iostream>
+#include <cstdio>
+#include <cstdlib>
 #include <signal.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -253,9 +253,9 @@ KdeSudo::KdeSudo(QWidget *parent, const char *name,const QString& icon, const QS
 			QStringList commandSplit = QStringList::split(" ", command);
 			for (int i = 0; i < commandSplit.count(); i++)
 			{
-				QString toto = validArg(commandSplit[i]);
-				*p << toto;
-				cmd += validArg(commandSplit[i]) + QChar(' ');
+				QString arg = validArg(commandSplit[i]);
+				*p << arg;
+				cmd += arg + QChar(' ');
 			}
 		}
 		else if (args->count())
@@ -310,7 +310,7 @@ void KdeSudo::receivedOut(KProcess*, char*buffer, int buflen)
 	pcTmp[buflen]='\0';
 	QString strOut(pcTmp);
 
-	std::cout << strOut << endl;
+	std::cout << strOut << std::endl;
 
 	static int badpass = 0;
 
