@@ -72,8 +72,8 @@ int main(int argc, char **argv)
 
 	KApplication a;
 
-	QString strCmd;
 	QString executable;
+	QStringList executableList;
 	QString arg;
 	QString command;
 	QStringList commandlist;
@@ -81,6 +81,9 @@ int main(int argc, char **argv)
 
 	bool withIgnoreButton = args->isSet("ignorebutton");
 
+	if (args->isSet("c"))
+		executable = args->getOption("c");
+
 	if (args->count())
 	{
 		if (executable.isEmpty())
@@ -91,9 +94,18 @@ int main(int argc, char **argv)
 		}
 	}
 
+	/* We have to make sure the executable is only the binary name */
+	executableList = QStringList::split(" ", executable);
+	executable = executableList[0];
+
+	executableList = QStringList::split("/", executable);
+	int i = executableList.count() - 1;
+	executable = executableList[i];
+
 	/* Kubuntu has a bug in it - this is a workaround for it */  
 	KGlobal::dirs()->addResourceDir("apps","/usr/share/applications/kde");
 	KGlobal::dirs()->addResourceDir("apps","/usr/share/applications");
+
 	QString deskFilePath = KGlobal::dirs()->findResource("apps",executable + ".desktop");
 	KDesktopFile desktopFile(deskFilePath,true);
 
